#!/bin/sh

#------------ Backup Function ------------

#------------ parameter   ------------
#TwsBackAction.sh <TWS home path>
#                 <backup path>
#		  <file containing the list of executable files>
#		  <file containing the list of configuration files>

#------------ exit value  ------------
#  1     "The backup process is not able to create the backup directory"
#  2     "The file containing the list of executable files is missing"
#  3     "The file containing the list of configuration files is missing"
#  4     "Change directory to TWS home path Failed"

CMD_LINE_ARGS=$*; export CMD_LINE_ARGS
#for ACT_ARG in $CMD_LINE_ARGS

#do
#  echo "PARAMETER:<$ACT_ARG>"
#done

#echo "twsBackupActionIsWorking........"



#set -vx

#------- get the parametres from the caller -------
  TWS_PREV_INST_DIR="$1"
  SAVE_DIR="$2"
  SAVE_FILE_LIST="$3"
  CFG_FILE_LIST="$4"
  verbose="$5"

#------- set needed variables -------
  TWS_END_DIR="`basename $TWS_PREV_INST_DIR`"
  PATH_OF_END_DIR="`dirname $TWS_PREV_INST_DIR`"
  FIRST_FILE="YES"
  REST_ACT_DIR=""
  SAVE_RC=0
  MAX_ERR_LEV=0
  ENV_UMASK=`umask`
  TEST_ERR_FILE="${TWS_PREV_INST_DIR}/updt_tws_82.err"
  FLAG=0

#------- verify the presence of the backup list file   --------
#echo "#------- verify the presence of the backup list file"

  if [ ! -f ${SAVE_FILE_LIST} ]
  then
    if [ "$verbose" = "-verbose" ]
    then
    echo "xxx #The list file ${SAVE_FILE_LIST} is missing." >&2
    fi
    exit 2
  fi


#------- verify the presence of the backup list file   --------
#echo "#------- verify the presence of the backup list file"

  if [ ! -f ${CFG_FILE_LIST} ]
  then
    if [ "$verbose" = "-verbose" ]
    then
    echo "xxx #The list file ${CFG_FILE_LIST} is missing." >&2
    fi
    exit 3
  fi


#------- calculate the directory where make the tar file -------
#------- make it if missing and verify the result of the --------
#------- operation                                      --------
#echo "#------- make it if missing and verify"





  if [ ! -d "$SAVE_DIR" ]
  then
    mkdir "$SAVE_DIR"
  fi

  if [ ! -d "$SAVE_DIR" ]
  then
  if [ "$verbose" = "-verbose" ]
    then
        echo "xxx #The backup process is not able to create the ${SAVE_DIR} directory." >&2
    fi
    exit 1
  fi

  chmod 755 "$SAVE_DIR"



#------- move the process to the TWS home directory and  -------
#------- verify the result of the operation              -------

  cd ${TWS_PREV_INST_DIR}

#  REST_ACT_DIR=`pwd`
#  if [ "$REST_ACT_DIR" != "$TWS_PREV_INST_DIR" ]
#  then
#   if [ "$verbose" = "-verbose" ]
#   then
#   echo "xxx #The change directory to $TWS_PREV_INST_DIR Failed." >&2
#   fi
#   exit 4
#  fi



#------- for each files or directory listed in the   -------
#------- Backup list file save it in the tar file    -------
#------- and verify the result of the operation      -------
#echo "#-------  Backup list file save it in the tar file             -------"
  cat ${SAVE_FILE_LIST} | while read file_to_save
  do
    if [ -f $file_to_save -o -d $file_to_save ]
    then
      if [ "$FIRST_FILE" = "YES" ]
      then
	tar cf "${SAVE_DIR}"/backup $file_to_save
        SAVE_RC=$?
        if [ $SAVE_RC -ne 0 ]
        then
          echo "WARNING :An Error occurred making the tar file needed for the Backup of the previous installation."
        fi
        FIRST_FILE="NO"
      else
	tar rf "${SAVE_DIR}"/backup $file_to_save
        SAVE_RC=$?
        if [ $SAVE_RC -ne 0 ]
        then
	  echo "WARNING :An Error occurred making the tar file needed for the Backup of the previous installation."
        fi
      fi
    fi
  done


  cat ${CFG_FILE_LIST} | while read file_to_save
  do

       PATH_OF_FILE="`dirname $file_to_save`"
#       echo "${SAVE_DIR}/${PATH_OF_FILE}"
       if [ ! -d "${SAVE_DIR}"/${PATH_OF_FILE} ]
       then
         umask 022
         mkdir -p  "${SAVE_DIR}"/${PATH_OF_FILE}
         if [ ! -d "${SAVE_DIR}"/${PATH_OF_FILE} ]
         then
           echo "WARNING : The backup process was not able to create the ${SAVE_DIR}/${TWS_END_DIR}/${PATH_OF_FILE} directory."
           MAX_ERR_LEV=2
         fi
         umask ${ENV_UMASK}
       fi
    if [ -f ${TWS_PREV_INST_DIR}/$file_to_save ]
    then
       cp -p ${TWS_PREV_INST_DIR}/$file_to_save "${SAVE_DIR}"/${PATH_OF_FILE}
       SAVE_RC=$?
       if [ ${SAVE_RC} -ne 0 ]
       then
         #echo "WARNING : The backup process was not able to copy $file_to_save into  ${SAVE_DIR}/${PATH_OF_FILE}/${file_to_save} directory."
          MAX_ERR_LEV=2
        fi
     fi
  done

#------- compress the Backup tar file            -------
#------- and verify the result of the operation  -------
#- use the compression tool supported by the Platform -
#echo "#-------compress the Backup tar file            -------"

 if [ "$COMPRESS_TOOL" = "" ]
 then
     compress -f "${SAVE_DIR}"/backup
     SAVE_RC=$?
  else
     $COMPRESS_TOOL -f "${SAVE_DIR}"/backup
     SAVE_RC=$?
  fi

  if [ $SAVE_RC -ne 0 ]
  then
    echo "A warning occurred compressing the tar file needed for the Backup of the previous installation."
  fi

  exit 0

