#!/bin/sh


#------- get the parametres from the caller -------
MAIN_DIR="$1"
INSTALL_DIR="$2"
MAEUSER="$3"
TWS_CPUTYPE="$4"
TWS_MASTER="$5"
TWS_THISCPU="$6"
SD_INST_LOG_FILE="$7"
VERBOSE="$8"

OS=`uname -s`;export OS
SD_CLI_DIR=$MAIN_DIR/CLI
ACTIONTOOLS_DIR=$MAIN_DIR/ACTIONTOOLS
TWSREGISTRYFILE=/etc/TWS/TWSRegistry.dat
STATUSDIR=$INSTALL_DIR/_uninstall/ACTIONTOOLS

BACKUPLOCALPATHVAR="$PATH"

# Vars fo CM execution
LD_LIBRARY_PATH=""; export LD_LIBRARY_PATH
LIBPATH=""; export LIBPATH
SHLIB_PATH=""; export SHLIB_PATH

#TWSRegistry
DIRTWSREGISTRYFILE=/etc/TWS
if [ ! -d "$DIRTWSREGISTRYFILE" ]
  then
    echo "create TWSREGISTRYFILE DIR "
    mkdir "$DIRTWSREGISTRYFILE"
    else
    echo "TWSREGISTRYFILE DIR exist"
fi

#Component
if [ -z "$UNISON_COMPONENT_FILE" ]
then
  UNISON_COMPONENT_FILE="/usr/unison/components"; export UNISON_COMPONENT_FILE
fi
echo "UNISON_COMPONENT_FILE=$UNISON_COMPONENT_FILE"

case $OS in
   AIX)
     INST_INTERP="AIX"; export INST_INTERP
   ;;
   HP-UX)
     INST_INTERP="HP"; export INST_INTERP
   ;;
   Linux)
     case `uname -m` in
     *86*)
       INST_INTERP="LINUX_I386"; export INST_INTERP
       ;;
     # For SuSE 9 64bit zSeries
     ia64)
       INST_INTERP="LINUX_S390"; export INST_INTERP
       ;;
     *390*)
       INST_INTERP="LINUX_S390"; export INST_INTERP
       ;;
     *) 
       INST_INTERP="LINUX_I386"; export INST_INTERP
       ;;       
     esac
   ;;
   SunOS)
     INST_INTERP="SOLARIS"; export INST_INTERP
   ;;
   *) 
     INST_INTERP="LINUX_I386"; export INST_INTERP
   ;;
esac

if [ "$VERBOSE" != "-verbose" ] 
then
  VERBOSE=""
fi

echo "twsCommitActionInProgress...."
echo "MAIN_DIR=$MAIN_DIR"
echo "INSTALL_DIR=$INSTALL_DIR"
echo "MAEUSER=$MAEUSER"
# Possible values: SA FTA MDM BKM
echo "TWS_CPUTYPE=$TWS_CPUTYPE"
echo "TWS_MASTER=$TWS_MASTER"
echo "TWS_THISCPU=$TWS_THISCPU"
echo "INST_INTERP=$INST_INTERP"
echo "ACTIONTOOLS_DIR=$ACTIONTOOLS_DIR"
echo "SD_INST_LOG_FILE=$SD_INST_LOG_FILE"
echo "SD_CLI_DIR=$SD_CLI_DIR"
echo "VERBOSE=$VERBOSE"

if [ -z "$MAEUSER" ]
then
  exit 1
fi


#
# execute_command is used to execute a command and capture errors.
#
# Arguments:
#	<command> args
execute_command()
{
 $@
 exitValue=$?
 if [ $exitValue -ne 0 ]
 then
   if [ "$VERBOSE" != "-verbose" ]
   then
     echo "The following command failed: $@." >&2
   else
     echo "$@." >&2
   fi
   
   PATH="$BACKUPLOCALPATHVAR"
   exit $exitValue
 fi
}


#
#
# Start of Main Script Logic.
#

cd ${INSTALL_DIR}
PATH="$BACKUPLOCALPATHVAR"

# TWS environment
. ./tws_env.sh
 
# Copy old security file if migrating an instance pre 8.2
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: NO
# Scenario Patch: NO
if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
if [ ! -f "$STATUSDIR/8.2_DISCOVERY.historyFile" ]
then
if [ -f "../unison/Security" ]
then
  rm -f $INSTALL_DIR/Security
  echo "Copy security file from unison dir..."
  execute_command "cp ../unison/Security $INSTALL_DIR/Security"
fi
fi
fi

if [ ! -f "$INSTALL_DIR/Security" ]
then
  echo "Creating security file..."
  execute_command "makesec -l Security.conf"
else
  echo "Skipping security file creation"
fi

# Set permission on security file
execute_command chown $MAEUSER $INSTALL_DIR/Security



# Create cpu in DB using composer
# Scenario Fresh: YES
# Scenario Upgrade: NO
# Scenario Promote: YES
# Scenario Patch: NO
if [ ! -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

# Possible values: master, bkm_agent, ft_agent, st_agent
if [ "$TWS_CPUTYPE" = "MDM" ]
then
  if [ -f $INSTALL_DIR/cpudef_unix ]
  then
    echo "Updating DB file..."
    execute_command "composer replace cpudef_unix"    
  fi
fi

fi
fi



# *****************
# CLEAN ENVIRONMENT
# *****************


echo "Before Updating TWSRegistry.dat"


# TWSREGISTRY.DAT CLEANING *****
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: NO
# Scenario Patch: NO

if [ ! -f "$TWSREGISTRYFILE" ]
then
  echo "Creating TWSRegistryFile..."
  echo " " > $TWSREGISTRYFILE
fi

# first try to add a row to catch error before cleaning action....
twsRegistryKey="/Tivoli/Workload_Scheduler/$MAEUSER"

# Promote does not modify TWSRegistry entries, only agent type
if [ ! -f "$STATUSDIR/FLOW_PROMOTE.historyFile" ]
then
if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_objectClass $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PackageName $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MajorVersion $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MinorVersion $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PatchVersion $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FeatureList $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ProductID $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ou $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_InstallationPath $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_UserOwner $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MaintenanceVersion $VERBOSE"
execute_command "$cmd"



# TWSREGISTRY.DAT ADDING   *****
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_objectClass=OU $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PackageName=FP_TWS_${INST_INTERP}_${MAEUSER}.8.2.1.00 $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MajorVersion=8 $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MinorVersion=2 $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_PatchVersion= $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FeatureList= $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ProductID=TWS_ENGINE $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_ou=$MAEUSER $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_InstallationPath=$INSTALL_DIR $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_UserOwner=$MAEUSER $VERBOSE"
execute_command "$cmd"
cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_MaintenanceVersion=1 $VERBOSE"
execute_command "$cmd"

fi
fi

# Update Agent info in TWSRegistry.dat file
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO

if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then

cmd="$ACTIONTOOLS_DIR/TWSupdate_file -delRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent $VERBOSE"
execute_command "$cmd"
  
if [ "$TWS_CPUTYPE" = "SA" ]
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=SA $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "FTA" ] 
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=FTA $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "MDM" ]
then 
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=MDM $VERBOSE"
  execute_command "$cmd"
fi

if [ "$TWS_CPUTYPE" = "BKM" ] 
then
  cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_Agent=BKM $VERBOSE"
  execute_command "$cmd"
fi

fi


# *** FIXPACK ONLY ***
# Scenario Fresh: NO
# Scenario Upgrade: NO
# Scenario Promote: NO
# Scenario Patch: YES

# SPB will execute this step
#  if [ -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
#  then   
#    cmd="$ACTIONTOOLS_DIR/TWSupdate_file -addRow $TWSREGISTRYFILE ${twsRegistryKey}_DN_FixpackName=FP_TWS_${INST_INTERP}_$MAEUSER.8.2.1.01 $VERBOSE"
#    execute_command "$cmd"  
#  fi
  

echo "After Updating TWSRegistry.dat"


# Verbose is activated only for SPB installation, in this case commit can't do the following...
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO

if [ ! -f "$STATUSDIR/METHOD_CM.historyFile" ]
then
  if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
  then

      cd "$SD_CLI_DIR"
      PATH="$BACKUPLOCALPATHVAR"
      . ./swd_env.sh
      
      #----- COMMIT LANG SPB ACTION -------------------------------------------

      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      LANG_PKG_NAME="TWS_LP_${MAEUSER}.8.2.1.00"
      INST_CMD_LINE="wdacptsp ${LANG_PKG_NAME}"

      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?

      if [ $ACTION_TOOL_RET_COD -ne 0 -a $ACTION_TOOL_RET_COD -ne 7 ]
      then
        ACTION_TOOL_RET_COD=1
      fi
      if [ $ACTION_TOOL_RET_COD -eq 7 ]
      then
        ACTION_TOOL_RET_COD=0
      fi

      # Print Debug Information
      echo "commitLangSPBAction"
      echo "$ACTION_TOOL_RET_STDOUT"

      # Action Result Handling
       if [ $ACTION_TOOL_RET_COD -ne 0 ]
       then
         echo "PROBLEMS FOUND"         
      #   exit 1      
       fi


      #----- END ACTION ------------------------------------------

      



      #----- COMMIT ENGINE SPB ACTION -------------------------------------------
      
      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      INST_PKG_NAME="FP_TWS_${INST_INTERP}_${MAEUSER}.8.2.1.00"
      INST_CMD_LINE="wdacptsp ${INST_PKG_NAME}"
            
      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?    
      
      if [ $ACTION_TOOL_RET_COD -ne 0 -a $ACTION_TOOL_RET_COD -ne 7 ]
      then
        ACTION_TOOL_RET_COD=1        
      fi
      if [ $ACTION_TOOL_RET_COD -eq 7 ]
      then
        ACTION_TOOL_RET_COD=0
      fi


      # Print Debug Information 
      echo "commitEngineSPBAction"
      echo "$ACTION_TOOL_RET_STDOUT"
      
      # Action Result Handling 
      if [ $ACTION_TOOL_RET_COD -ne 0 ]
      then
        echo "PROBLEMS FOUND"
      #   exit 1      
      fi
  fi

      #----- END ACTION ------------------------------------------
      
      
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: YES
      
if [ -f "$MAIN_DIR/CLI/wconvcat_env.sh" ]
then
      #----- WCONVCAT FIX FOR CM ACTION -------------------------------------------
      
      ACTION_TOOL_RET_STDOUT="";export ACTION_TOOL_RET_STDOUT
      ACTION_TOOL_RET_COD=0

      cd "$SD_CLI_DIR"
      PATH="$BACKUPLOCALPATHVAR"
      . ./swd_env.sh
      . ./wconvcat_env.sh

      INST_CMD_LINE="wconvcat -d"

      # Call SPB script
      ACTION_TOOL_RET_STDOUT=`${INST_CMD_LINE}`
      ACTION_TOOL_RET_COD=$?    

      # Print Debug Information 
      echo "fixCMCatalogAction"
      echo "$ACTION_TOOL_RET_STDOUT"
      
      # Action Result Handling 
      if [ $ACTION_TOOL_RET_COD -ne 0 ]
      then
        echo "wconvcat: PROBLEMS FOUND"
      #   exit 1      
      fi


      #----- END ACTION ------------------------------------------
fi

  PATH="$BACKUPLOCALPATHVAR"
  cd "$MAIN_DIR"

# not in CM scenario end if  
fi



# CLEANING ACTION

# Remove Symphony only promote scenario
# Scenario Fresh: NO
# Scenario Upgrade: NO
# Scenario Promote: YES
# Scenario Patch: NO
if [ -f "$STATUSDIR/FLOW_PROMOTE.historyFile" ]
then

  if [  -f $INSTALL_DIR/Symphony ]
  then
  if [ "$TWS_CPUTYPE" = "MDM" ]
  then
    echo "Removing Symphony"
    rm -rf $INSTALL_DIR/Symphony
  fi
  if [ "$TWS_CPUTYPE" = "BKM" ]
  then
    echo "Removing Symphony"
    rm -rf $INSTALL_DIR/Symphony
  fi
  fi
fi



# Clean binaries for different agents
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO

REMOVEDELTA_MASTER="false"
REMOVEDELTA_FTA="false"

if [ "$TWS_CPUTYPE" = "SA" ]
then
  REMOVEDELTA_MASTER="true"
  REMOVEDELTA_FTA="true"
fi
if [ "$TWS_CPUTYPE" = "FTA" ]
then
  REMOVEDELTA_MASTER="true"
fi

if [ -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then
  REMOVEDELTA_MASTER="false"
  REMOVEDELTA_FTA="false"
fi

if [ "$REMOVEDELTA_MASTER" = "true" ]
then
  echo "Removing delta Master file..."

  rm -f $INSTALL_DIR/Jnextday
  rm -f $INSTALL_DIR/Sfinal
  rm -f $INSTALL_DIR/cpudef_unix
  rm -f $INSTALL_DIR/rm_Symphony

  rm -f $INSTALL_DIR/demo/skedlist
  rm -f $INSTALL_DIR/demo/sgl
  rm -f $INSTALL_DIR/demo/sarec
  rm -f $INSTALL_DIR/demo/sapay
  rm -f $INSTALL_DIR/demo/jgljob2
  rm -f $INSTALL_DIR/demo/jgljob1
  rm -f $INSTALL_DIR/demo/jdemojcl
  rm -f $INSTALL_DIR/demo/jarjob2
  rm -f $INSTALL_DIR/demo/jarjob1
  rm -f $INSTALL_DIR/demo/japjob2
  rm -f $INSTALL_DIR/demo/japjob1
  rm -f $INSTALL_DIR/demo/expskedlist
  rm -f $INSTALL_DIR/demo/expsetup
  rm -f $INSTALL_DIR/demo/expgl
  rm -f $INSTALL_DIR/demo/exparec
  rm -f $INSTALL_DIR/demo/expapay
  rm -f $INSTALL_DIR/demo/demosetup
  rm -f $INSTALL_DIR/demo/demonetcpu
  rm -f $INSTALL_DIR/demo/democpu

  rm -f $INSTALL_DIR/bin/archiver
  rm -f $INSTALL_DIR/bin/xrxtrct
  rm -f $INSTALL_DIR/bin/xref
  rm -f $INSTALL_DIR/bin/stageman
  rm -f $INSTALL_DIR/bin/schedulr
  rm -f $INSTALL_DIR/bin/reptr
  rm -f $INSTALL_DIR/bin/rextract
  rm -f $INSTALL_DIR/bin/reporter
  rm -f $INSTALL_DIR/bin/report8
  rm -f $INSTALL_DIR/bin/report7
  rm -f $INSTALL_DIR/bin/report4b
  rm -f $INSTALL_DIR/bin/report4a
  rm -f $INSTALL_DIR/bin/report3
  rm -f $INSTALL_DIR/bin/report2
  rm -f $INSTALL_DIR/bin/report11
  rm -f $INSTALL_DIR/bin/report1
  rm -f $INSTALL_DIR/bin/rep8
  rm -f $INSTALL_DIR/bin/rep7
  rm -f $INSTALL_DIR/bin/rep4b
  rm -f $INSTALL_DIR/bin/rep4a
  rm -f $INSTALL_DIR/bin/rep3
  rm -f $INSTALL_DIR/bin/rep2
  rm -f $INSTALL_DIR/bin/rep11
  rm -f $INSTALL_DIR/bin/rep1
  rm -f $INSTALL_DIR/bin/r11xtr
  rm -f $INSTALL_DIR/bin/prxtract
  rm -f $INSTALL_DIR/bin/paxtract
  rm -f $INSTALL_DIR/bin/sorter
  rm -f $INSTALL_DIR/bin/makecal
  rm -f $INSTALL_DIR/bin/jbxtract
  rm -f $INSTALL_DIR/bin/dbinfo
  rm -f $INSTALL_DIR/bin/dbexpand
  rm -f $INSTALL_DIR/bin/crossref
  rm -f $INSTALL_DIR/bin/composer
  rm -f $INSTALL_DIR/bin/compiler
  rm -f $INSTALL_DIR/bin/caxtract
  rm -f $INSTALL_DIR/bin/syxtract
  
  rm -f $INSTALL_DIR/bin/logman
fi
if [ "$REMOVEDELTA_FTA" = "true" ]
then
  echo "Removing delta FTA file..."
  rm -f $INSTALL_DIR/bin/batchman
fi



echo "Removing old TWS version files..."
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO

if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
then
  
rm -f $INSTALL_DIR/bin/gcomposer
rm -f $INSTALL_DIR/bin/gcomposer.vhs
rm -f $INSTALL_DIR/bin/gcomposer.vr
rm -f $INSTALL_DIR/bin/gconman
rm -f $INSTALL_DIR/bin/gconman.vhs
rm -f $INSTALL_DIR/bin/gconman.vr
rm -f $INSTALL_DIR/bin/gjdlb
rm -f $INSTALL_DIR/bin/gjdlb.vr
rm -f $INSTALL_DIR/bin/gmaestro
rm -f $INSTALL_DIR/bin/gmaestro.vr

rm -f $INSTALL_DIR/bin/jhxtract
rm -f $INSTALL_DIR/bin/rmatjob
rm -f $INSTALL_DIR/bin/startcpu
rm -f $INSTALL_DIR/bin/stop
rm -f $INSTALL_DIR/bin/symread
rm -f $INSTALL_DIR/bin/tellop
rm -f $INSTALL_DIR/bin/unisubmit

rm -f $INSTALL_DIR/bin/vgalaxy2.vr
rm -f $INSTALL_DIR/bin/vhelpsrv
rm -f $INSTALL_DIR/bin/vhelpsrv.vhs
rm -f $INSTALL_DIR/bin/vhelpsrv.vr
rm -f $INSTALL_DIR/bin/visualm
rm -f $INSTALL_DIR/bin/visualm.vhs
rm -f $INSTALL_DIR/bin/visualm.vr
rm -f $INSTALL_DIR/bin/xcomposer
rm -f $INSTALL_DIR/bin/xcomposer.vr
rm -f $INSTALL_DIR/bin/xconman
rm -f $INSTALL_DIR/bin/xconman.vr
rm -f $INSTALL_DIR/bin/xmaestro
rm -f $INSTALL_DIR/bin/xmaestro.vr

# Old TWS8.2 uninstall dir
rm -fR ${INSTALL_DIR}/_uninst
rm -f $INSTALL_DIR/cpudef_unix
rm -f $INSTALL_DIR/rm_Symphony

fi



# Cleaning components file
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: NO
# Scenario Patch: NO
if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
  if [ -f "$UNISON_COMPONENT_FILE" ]
  then
    `$ACTIONTOOLS_DIR/TWSupdate_file -delRow "$UNISON_COMPONENT_FILE" ${MAEUSER}`
  fi
fi

rm -f $INSTALL_DIR/twsRestore.sh
rm -f $INSTALL_DIR/*.old
rm -f $INSTALL_DIR/mozart/*.old
rm -f $INSTALL_DIR/*.bck
rm -f $INSTALL_DIR/mozart/*.bck
rm -f $INSTALL_DIR/Tbsm/TbsmAdapter/*.bck
rm -f $STATUSDIR/*.historyFile

echo "Commit exited successfully"
exit 0

